@@ -16,3 +16,9 @@ rep.pin <- create_s3_method("rep")
   NextMethod()
 }
 
+#' @export
+c.pin <- function(..., recursive = FALSE){
+  args <- list(...)
+  if (!length(args)) return(as.pin(character()))
+  as.pin(unlist(lapply(args, as.character)))
+} 
