@@ -13,9 +13,8 @@ test_that(desc="Frequencies in test file: pin_sex",{
 })
 
 test_that(desc="Frequencies in test file: pin_age",{
-  # Skipped until lubridate 1.4 is on CRAN
-  #expect_equal(as.numeric(table(pin_age(test_pins$pin, "2015-01-01")))[c(1,2,10,50,99)], 
-  #             c(363,374,364,26,365))  
+  expect_equal(as.numeric(table(pin_age(test_pins$pin, "2015-01-01")))[c(1,2,10,50,99)], 
+               c(363,374,364,26,365))  
 })
 
 test_that(desc="Frequencies in test file: pin_ctrl",{
